You are not logged in.

#1 2010-06-25 21:12:48

sicpsnake
Member
From: Austin, TX.
Registered: 2010-02-25
Posts: 128
Website

Graphics Editor

So, I'm in the free market for a good graphics editor (will mainly be used for web design). Photoshop in wine is a trainwreck, the GIMP is bloated and doesn't have single window mode yet and I don't want to install QT for Krita.  I have tried a handle full of graphics software for GNU/Linux but the only one that is decent enough to use is Pinta, which is pretty unusable due to the occasional segfault. I really don't feel like installing Windows 7 in a VM just to use Photoshop, so my question is.....

Good grahics editor for GNU/Linux? Something comparable to Photoshop would be nice. smile

Offline

#2 2010-06-25 21:21:15

gtklocker
Member
Registered: 2009-09-01
Posts: 462

Re: Graphics Editor

Gimp has single window mode in its git version.

Offline

#3 2010-06-25 21:25:30

sicpsnake
Member
From: Austin, TX.
Registered: 2010-02-25
Posts: 128
Website

Re: Graphics Editor

gtklocker wrote:

Gimp has single window mode in its git version.

It's still incredibly bloated, though. I really don't feel like installing things like HAL and ten thousand other dependencies.. hmm I guess I may have to make a sacrifice.

Offline

#4 2010-06-25 21:38:03

archman-cro
Member
From: Croatia
Registered: 2010-04-04
Posts: 943
Website

Re: Graphics Editor

Isn't hal just an optional dep? Gimp is worth for you to get "bloated" cause it's really an amazing editor. ;D

Offline

#5 2010-06-25 23:47:00

anonymous_user
Member
Registered: 2009-08-28
Posts: 3,059

Re: Graphics Editor

I think GIMP is the closest you're gonna get to Photoshop at least in terms of features.

Offline

#6 2010-06-26 00:18:26

skottish
Forum Fellow
From: Here
Registered: 2006-06-16
Posts: 7,942

Re: Graphics Editor

Not trying to beat this one to death, but GIMP is by far the most feature complete bitmap editor in the 'free' world. While it lags far behind Photoshop in a number of areas, extending it through scripting puts it in a class of its own in many ways.

Of course, no FOSS toolkit would be complete without Inkscape.

Offline

#7 2010-06-26 00:33:13

sicpsnake
Member
From: Austin, TX.
Registered: 2010-02-25
Posts: 128
Website

Re: Graphics Editor

I am trying out GIMP now and even with single window mode it feels incredibly awkward. Such a dilema. I guess I'll have to learn to get used to it.

Offline

#8 2010-06-26 00:42:03

harryNID
Member
From: P3X-1971
Registered: 2009-06-12
Posts: 117

Re: Graphics Editor

You could try this:

gimpshop:
http://www.archlinux.org/packages/commu … /gimpshop/

home page:
http://www.gimpshop.com/

It's in the repos.  It's a custom version of gimp made to resemble Photoshop.

Now if that is still too bloated for you some custom building is in order to make it smaller. I won't go into that but it's pretty easy to do just read the wiki.

I build a stripped down version of regular gimp for myself based originally on the gimp-light package in AUR.

If your interested here it is:

PKGBUILD (Note: Be sure to make the md5sums! See Below.)

# Contributor: Christoph Zeiler <archNOSPAM_at_moonblade.dot.org>
# Contributor: tobias <tobias@archlinux.org>
# Custom by harryNID

pkgname=gimp-light
pkgver=2.6.9
pkgrel=1
pkgdesc="A lightweight variant of the GNU Image Manipulation Program"
arch=('i686' 'x86_64')
url="http://www.gimp.org/"
license=('GPL')
depends=( 'gtk2>=2.14.4' 'libxpm>=3.5.7' 'libxmu>=1.0.4' 'librsvg>=2.14' \
     'dbus-glib>=0.70' 'libexif>=0.6.15' 'gegl>=0.0.18')
optdepends=('gimp-help-2 (documentation)')
makedepends=('intltool>=0.36.3' 'pkgconfig>=0.16' \
    'babl>=0.0.22')
provides=('gimp')
conflicts=('gimp')
options=('!libtool')
install=$pkgname.install
source=(ftp://ftp.gimp.org/pub/gimp/v2.6/gimp-$pkgver.tar.bz2
        linux.gpl libpng-1.4.patch \
    zoom.patch)

build() {
  cd gimp-$pkgver
#patch -p1 < ../libpng-1.4.patch || return 1
#patch -p1 < ../zoom.patch || return 1
  ./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --disable-python \
    --disable-gimp-console \
    --without-aa \
    --without-webkit \
    --without-poppler \
    --without-gvfs \
    --without-gnomevfs \
    --without-libcurl \
    --without-wmf \
    --without-lcms \
    --without-alsa \
    --without-linux-input \
    --without-wmf \
    --without-libmng \
    --without-lcms \
    --without-print \
    --disable-alsatest


  make || return 1
  make DESTDIR="$pkgdir" install

  install -Dm644 ../linux.gpl "$pkgdir"/usr/share/gimp/2.0/palettes/linux.gpl
}

# vim:set ts=2 sw=2 et:

gimp-light.install

post_install() {
  update-desktop-database -q
  gtk-update-icon-cache -q -t -f usr/share/icons/hicolor
}

post_upgrade() {
  post_install
}

post_remove() {
  post_install
}

libpng-1.4.patch

diff -Naur gimp-2.7.0-orig/plug-ins/file-ico/ico-load.c gimp-2.7.0/plug-ins/file-ico/ico-load.c
--- gimp-2.7.0-orig/plug-ins/file-ico/ico-load.c    2010-01-18 19:01:46.000000000 -0500
+++ gimp-2.7.0/plug-ins/file-ico/ico-load.c    2010-01-18 19:14:43.000000000 -0500
@@ -286,14 +286,22 @@
   switch (color_type)
     {
     case PNG_COLOR_TYPE_GRAY:
+#if PNG_LIBPNG_VER < 10400
       png_set_gray_1_2_4_to_8 (png_ptr);
+#else
+      png_set_expand_gray_1_2_4_to_8(png_ptr);
+#endif
       if ( bit_depth == 16 )
         png_set_strip_16 (png_ptr);
       png_set_gray_to_rgb (png_ptr);
       png_set_add_alpha (png_ptr, 0xff, PNG_FILLER_AFTER);
       break;
     case PNG_COLOR_TYPE_GRAY_ALPHA:
+#if PNG_LIBPNG_VER < 10400
       png_set_gray_1_2_4_to_8 (png_ptr);
+#else
+      png_set_expand_gray_1_2_4_to_8(png_ptr);
+#endif
       if ( bit_depth == 16 )
         png_set_strip_16 (png_ptr);
       png_set_gray_to_rgb (png_ptr);

linux.gpl

GIMP Palette
Name: linux
#
  0   0   0
  0   0 170
  0 170   0
  0 170 170
170   0   0
170   0 170
170  85   0
170 170 170
 85  85  85
 85  85 255
 85 255  85
 85 255 255
255  85  85
255  85 255
255 255  85
255 255 255

zoom.patch

From 501c4f65f08c111df0654cb887d95c2c06e82710 Mon Sep 17 00:00:00 2001
From: Nils Philippsen <nils@redhat.com>
Date: Wed, 24 Mar 2010 17:08:01 +0000
Subject: backport statusbar code needed for GTK+ >= 2.19.1

Use the hbox that is provided via gtk_statusbar_get_message_area()
since GTK+ 2.19.1.
---
diff --git a/app/display/gimpstatusbar.c b/app/display/gimpstatusbar.c
index 5e89427..36651cd 100644
--- a/app/display/gimpstatusbar.c
+++ b/app/display/gimpstatusbar.c
@@ -49,6 +49,9 @@
 /*  maximal width of the string holding the cursor-coordinates  */
 #define CURSOR_LEN        256
 
+/*  the spacing of the hbox                                     */
+#define HBOX_SPACING        1
+
 /*  spacing between the icon and the statusbar label            */
 #define ICON_SPACING        2
 
@@ -152,6 +155,7 @@ static void
 gimp_statusbar_init (GimpStatusbar *statusbar)
 {
   GtkWidget     *hbox;
+  GtkWidget     *label;
   GtkWidget     *image;
   GimpUnitStore *store;
 
@@ -171,13 +175,27 @@ gimp_statusbar_init (GimpStatusbar *statusbar)
   statusbar->progress_active      = FALSE;
   statusbar->progress_shown       = FALSE;
 
-  /* remove the label and insert a hbox */
-  gtk_container_remove (GTK_CONTAINER (GTK_STATUSBAR (statusbar)->frame),
-                        g_object_ref (GTK_STATUSBAR (statusbar)->label));
-
-  hbox = gtk_hbox_new (FALSE, 1);
-  gtk_container_add (GTK_CONTAINER (GTK_STATUSBAR (statusbar)->frame), hbox);
-  gtk_widget_show (hbox);
+  label = g_object_ref (GTK_STATUSBAR (statusbar)->label);
+
+  /* remove the message area or label and insert a hbox */
+#if GTK_CHECK_VERSION (2, 19, 1)
+  {
+    hbox = gtk_statusbar_get_message_area (GTK_STATUSBAR (statusbar));
+    gtk_box_set_spacing (GTK_BOX (hbox), HBOX_SPACING);
+    gtk_container_remove (GTK_CONTAINER (hbox), label);
+  }
+#else
+  {
+    GtkWidget *label_parent;
+
+    label_parent = gtk_widget_get_parent (label);
+    gtk_container_remove (GTK_CONTAINER (label_parent), label);
+
+    hbox = gtk_hbox_new (FALSE, HBOX_SPACING);
+    gtk_container_add (GTK_CONTAINER (label_parent), hbox);
+    gtk_widget_show (hbox);
+  }
+#endif
 
   statusbar->cursor_label = gtk_label_new ("8888, 8888");
   gtk_misc_set_alignment (GTK_MISC (statusbar->cursor_label), 0.5, 0.5);
--
cgit v0.8.3.1

Just mkdir gimp-light  in your build directory and add all the files inside (make sure to name them exactly what I have above each one. After you do that cd to gimp-light directory and issue: (this command could change depending on wheather you are using root or fakeroot)

makepkg -g >> PKGBUILD

This will append the md5sums in the PKGBUILD so you can build. I did it like this in case you added a space while copying that could potentially change my original md5sums. This will remake them to how you saved them.

After that just build normally. If it all worked you should have a bare version of the gimp that is still fully functional, well for what I use it for anyway!

Another quick note:

If you are familiar with Photoshop then this is a good script to have for gimp. It mimics the Layer Effects just like Photoshop. Just follow the directions to install.

GIMP Plugin Registry
Layer Effects
http://registry.gimp.org/node/186


In solving a problem of this sort, the grand thing is to be able to reason backward. That is a very useful accomplishment, and a very easy one, but people do not practice it much. In the everyday affairs of life it is more useful to reason forward, and so the other comes to be neglected. There are fifty who can reason synthetically for one who can reason analytically.  --Sherlock Holmes

Offline

Board footer

Powered by FluxBB